pub enum FormFieldType {
Text {},
Password {},
CheckBox {},
Number {},
Range {},
DateTime {},
Date {},
Time {},
Select {
values: Vec<String>,
default: usize,
},
}Expand description
All the possible form field type with their configs if needed.
Variants
Text
A simple text input
Password
A text input with hidden characters
CheckBox
A simple boolean input (checkbox like)
Number
A number input
Range
A range between two numbers
DateTime
A date and time input
Date
A date only input
Time
A time only input
Select
A select input with a list of values and a default index