pub enum FormNode<FID>where
FID: EzCptIds,{
Field(FormField<FID>),
Form(Form<FID>),
}Expand description
A form node is either a field or whole sub-form.
Variants
Field(FormField<FID>)
A single field in the form.
Form(Form<FID>)
A sub-form that can contain multiple fields or other sub-forms.