SubClause

Enum SubClause 

pub enum SubClause<CID, SID>
where CID: EzCptIds, SID: EzShipIds,
{ Always, HasAttrValue(SubId<CID, SID>, Attribute, AttrValue), IsActive(SubId<CID, SID>), Not(Box<SubClause<CID, SID>>), And(Box<SubClause<CID, SID>>, Box<SubClause<CID, SID>>), Or(Box<SubClause<CID, SID>>, Box<SubClause<CID, SID>>), Xor(Box<SubClause<CID, SID>>, Box<SubClause<CID, SID>>), }
SubClause defines unde what conditions the event should be forwarded to the target based on its state.

Variants



Always

Always true



HasAttrValue(SubId<CID, SID>, Attribute, AttrValue)

Check if the target has an attribute with a specific value



IsActive(SubId<CID, SID>)

Check if the target is mounted/registerd depending if it’s a component or a ship



Not(Box<SubClause<CID, SID>>)

Negate another clause



And(Box<SubClause<CID, SID>>, Box<SubClause<CID, SID>>)

Combine two clauses with AND



Or(Box<SubClause<CID, SID>>, Box<SubClause<CID, SID>>)

Combine two clauses with OR



Xor(Box<SubClause<CID, SID>>, Box<SubClause<CID, SID>>)

Combine two clauses with XOR

Implementations

Source

impl<CID, SID> SubClause<CID, SID>
where CID: EzCptIds, SID: EzShipIds,

pub fn not(clause: Self) -> Self

Create a new clause that is the inverse of the given clause

pub fn and(a: Self, b: Self) -> Self

Create a new clause that is true if the two clauses are true

pub fn or(a: Self, b: Self) -> Self

Create a new clause that is true if at least one of the two clauses is true

pub fn xor(a: Self, b: Self) -> Self

Create a new clause that is true if one and only one of the two clauses is true