pub enum SubId<CID, SID>{
CPt(EzCptId<CID>),
Ship(EzShipId<SID>),
}Expand description
Every subscription target is either for a [Component] or a [Ship].
We wrap the id of that target inside this enum to know if it refers to a component or a ship.
Variants