CustomLayout

Struct CustomLayout 

pub struct CustomLayout<CID>
where CID: EzCptIds,
{ /* private fields */ }
A layout wrapper that makes it easy to create nested layouts.

Implementations

Source

impl<CID> CustomLayout<CID>
where CID: EzCptIds,

pub fn named<S: Into<String>>( name: S, layout: Layout, items: VecDeque<LayoutItem<CID>>, ) -> Result<Self>

Create a new CustomLayout with a name

Errors
  • [LayoutError::MismatchConstraintsAndCpts] if the number of areas generated by the layout does not match the number of items in the layout.
pub fn split(&self, area: Rect) -> Vec<(Rect, &LayoutItem<CID>)>

Splits the given area based on the underlying layout.

pub fn contains(&self, id: &CID) -> bool

Check if the layout contains a component with the given id