pub struct FieldResult<FID>where
FID: EzCptIds,{ /* private fields */ }Expand description
A type wrapping a form field and its value.
Implementations
Sourceimpl<FID> FieldResult<FID>where
FID: EzCptIds,
impl<FID> FieldResult<FID>where
FID: EzCptIds,
Sourcepub fn as_datetime(&self) -> Option<DateTime<Utc>>
pub fn as_datetime(&self) -> Option<DateTime<Utc>>
Try to return this field result as a date and time value.