pub struct Form<FID>where
FID: EzCptIds,{ /* private fields */ }Expand description
Describes a whole form, which can contain multiple fields and sub-forms. As a form has a fixed layout direction, sub forms can be used to change the direction.
Implementations
Sourceimpl<FID> Form<FID>where
FID: EzCptIds,
impl<FID> Form<FID>where
FID: EzCptIds,
Sourcepub fn custom_layout(&self) -> CustomLayout<FID>
pub fn custom_layout(&self) -> CustomLayout<FID>
Compute and return the layout of this form
Sourcepub fn flatten_fields(&self) -> Vec<&FormField<FID>>
pub fn flatten_fields(&self) -> Vec<&FormField<FID>>
Flatten all fields in this form and its sub-forms into a single Vec.