FormCpt

Struct FormCpt 

pub struct FormCpt<FID, CID, CA, CS, CM>
where FID: EzCptIds, CID: EzCptIds, CA: EzArgs, CS: EzState, CM: EzMsg,
{ /* private fields */ }
A component responsible for rendering a form.

Implementations

Source

impl<FID, CID, CA, CS, CM> FormCpt<FID, CID, CA, CS, CM>
where FID: EzCptIds, CID: EzCptIds, CA: EzArgs, CS: EzState, CM: EzMsg,

pub fn new(form: Form<FID>) -> Self

Create a new FormCpt component with a given form.

pub fn collect(&self) -> FormResult<FID>

Collect this form result as a FormResult.

pub fn capture_validation(&mut self) -> bool

Pass the validation event of this form to all its inputs so they can act on it and return wether or not validation has been handled internally.