pub struct IndicatorMock { /* private fields */ }Expand description
A mock component to display a colored indicator inside the TUI. The indicator is a simple box alternating its style from a given set of Style when Self::cycle is called.
Implementations
Sourceimpl IndicatorMock
impl IndicatorMock
Sourcepub fn with_palette(name: String, palette: &EzPalette) -> Self
pub fn with_palette(name: String, palette: &EzPalette) -> Self
Create a new IndicatorMock component with two styles derived from one [Palette].
Sourcepub fn with_palettes(
name: String,
palette_a: &EzPalette,
palette_b: &EzPalette,
) -> Self
pub fn with_palettes( name: String, palette_a: &EzPalette, palette_b: &EzPalette, ) -> Self
Create a new IndicatorMock component with two styles derived from two [Palette].