pub struct LogsMock { /* private fields */ }Expand description
A generic mock component to display logs inside the TUI
This mock initializes tui_logger and so it should be instantiated only once.
Implementations