pub struct MouseEventClause {
pub kind: MouseEventKind,
pub modifiers: KeyModifiers,
pub column: Range<u16>,
pub row: Range<u16>,
}Expand description
Struct to be more specific on the mouse event clause. Allow checking the range of the event and any modifiers.
Fields
kind: MouseEventKindthe MouseEventKind of the event (click, drag, etc.)
modifiers: KeyModifiersthe KeyModifiers of the event (ctrl, shift, etc.)
column: Range<u16>range of acceptable columns
row: Range<u16>range of acceptable rows