Port

Struct Port 

pub struct Port<CID, SID, CA, CS, CM>
where SID: EzShipIds, CA: EzArgs, CS: EzState, CM: EzMsg,
{ /* private fields */ }
The port is the struct that holds all your ships. Like the [View], you’ll only have one port in your app but as many ships as you want. Again like the [View], the port is the orchestrator of your ships. It will send the forward to/from the ships and your app.

Implementations

Source

impl<CID, SID, CA, CS, CM> Port<CID, SID, CA, CS, CM>
where CID: EzCptIds, SID: EzShipIds, CA: EzArgs, CS: EzState, CM: EzMsg,

pub fn init(&mut self, tx: &Sender<EzEvent<CID, CM>>)

Initialize a new empty port

pub fn register( &mut self, id: SID, ship: BoxedShip<CID, CA, CS, CM>, ) -> Result<()>

Add a new ship to the port

Errors
pub fn unregister(&mut self, id: &SID) -> Result<()>

Remove the ship with given id from the port

Errors
pub fn registered(&self, id: &SID) -> bool

Check if the ship with given id is registered in the port

pub fn query_ship( &self, _: &EzShipId<SID>, _: Attribute, ) -> Result<Option<AttrValue>>

Query a component for an attribute

Errors

None for now

pub fn set_ship_attr( &mut self, _: &EzShipId<SID>, _: Attribute, _: AttrValue, ) -> Result<()>

Set an attribute to a component

Errors

None for now