RenderIndicatorCpt

Struct RenderIndicatorCpt 

pub struct RenderIndicatorCpt<CA, CM>
where CA: EzArgs, CM: EzMsg,
{ /* private fields */ }
A component to display a colored indicator alternating colors based on the frame rate of the terminal.

Implementations

Source

impl<CA, CM> RenderIndicatorCpt<CA, CM>
where CA: EzArgs, CM: EzMsg,

pub fn with_palette(palette: &EzPalette) -> Self

Create a new RenderIndicatorCpt component with two styles derived from one [Palette].

pub fn with_palettes(palette_a: &EzPalette, palette_b: &EzPalette) -> Self

Create a new RenderIndicatorCpt component with two styles derived from two [Palette]s.