pub struct Theme {
pub text_palette: EzPalette,
pub main_palette: EzPalette,
pub accent_palette: EzPalette,
pub default_style: Style,
pub alternate_style: Option<Style>,
pub default_border_theme: BorderTheme,
pub alternate_border_theme: Option<BorderTheme>,
}Expand description
Holds some commonly used style across your application
Fields
text_palette: EzPaletteThe text color of the application
main_palette: EzPaletteThe main color of the application. This will be used mainly for blocks borders
accent_palette: EzPaletteAn accent color mainly used for focused blocks.
default_style: StyleA common style applied everywhere we can
alternate_style: Option<Style>An alternate version of the default style. This is used for focused blocks.
default_border_theme: BorderThemeA common style for all borders
alternate_border_theme: Option<BorderTheme>An alternate version of the default border theme. This is used for focused blocks.
Implementations
Sourceimpl Theme
impl Theme
Sourcepub fn block<'a>(&self, overide: Option<&Props>) -> Block<'a>
pub fn block<'a>(&self, overide: Option<&Props>) -> Block<'a>
Create a new block themed depending on its focus
Sourcepub fn get_reversed_style(&self, overide: Option<&Props>) -> Style
pub fn get_reversed_style(&self, overide: Option<&Props>) -> Style
Get the style for a given focus flag
Sourcepub fn get_border(&self, overide: Option<&Props>) -> BorderTheme
pub fn get_border(&self, overide: Option<&Props>) -> BorderTheme
Get the border theme for a given focus flag
Sourcepub fn main_or_accent(&self, condition: bool) -> EzPalette
pub fn main_or_accent(&self, condition: bool) -> EzPalette
Sourcepub fn main_or_text(&self, condition: bool) -> EzPalette
pub fn main_or_text(&self, condition: bool) -> EzPalette
Sourcepub fn accent_or_text(&self, condition: bool) -> EzPalette
pub fn accent_or_text(&self, condition: bool) -> EzPalette