pub struct TickIndicatorCpt<CA, CM>{ /* private fields */ }Expand description
A component to display a colored indicator alternating colors based on the tick rate of the terminal.
Implementations
Sourceimpl<CA, CM> TickIndicatorCpt<CA, CM>
impl<CA, CM> TickIndicatorCpt<CA, CM>
Sourcepub fn with_palette(palette: &EzPalette) -> Self
pub fn with_palette(palette: &EzPalette) -> Self
Create a new TickIndicatorCpt component with two styles derived from one [Palette].
Sourcepub fn with_palettes(palette_a: &EzPalette, palette_b: &EzPalette) -> Self
pub fn with_palettes(palette_a: &EzPalette, palette_b: &EzPalette) -> Self
Create a new TickIndicatorCpt component with two styles derived from two [Palette]s.