pub enum EventClause<CID, CM>{
Any,
Keyboard(KeyEvent),
Mouse(MouseEventClause),
WindowResize,
Init,
Lifecycle,
AnyClient,
Client(CM),
Specific(EzEvent<CID, CM>),
}Expand description
EventClause can be seen as categories of events. When you want a target to listen for events, you don’t subscribe to this event explicitly but to its category.
Variants
Any
Any event
Keyboard(KeyEvent)
Any keyboard event
Mouse(MouseEventClause)
Any mouse event
WindowResize
Only window resize events
Init
Only init events
Lifecycle
Only render events
AnyClient
Any client event
Client(CM)
A specific client event
Specific(EzEvent<CID, CM>)
A specific event