pub enum EzEvent<CID, CM>{
}Expand description
All the events that can be sent across the application.
Your custom events will be wrapped inside EzEvent::Client.
Variants
Keyboard(KeyEvent)
A keyboard event from crossterm
Mouse(MouseEvent)
A mouse event from crossterm
WindowResize(u16, u16)
A window resize event from crossterm
ForceFocus(EzCptId<CID>)
Force the focus to a given component ID.
ForceBlur()
Force the blur of the current focused component.
FocusGained
A focus gained event from crossterm. This is unrelated to the focus in-app; it means the terminal holding your app received focus from your window manager.
FocusLost
A focus lost event from crossterm. This is unrelated to the focus in-app; it means the terminal holding your app received focus from your window manager.
Paste(String)
A paste event from crossterm
Init
The event send after app is started
Tick
The event send on each tick (not used by the lib)
Render
The event send to trigger a render
Quit
The vent sent to order the app to gracefully exit
None
An empty event to be returned when no event is emited, but we want to prevent the default app event handling (focus/quit)
Error(Error)
Sent when an unexpected error occurs
UpdateLegend(String, Vec<Matcher>)
Set the dynamic legend
Client(CM)
Wraps any events related to your business logic.
Implementations
Sourceimpl<CID, CM> EzEvent<CID, CM>
impl<CID, CM> EzEvent<CID, CM>
Sourceimpl<CID, CM> EzEvent<CID, CM>
impl<CID, CM> EzEvent<CID, CM>
Sourcepub fn try_original(&self) -> Option<CrosstermEvent>
pub fn try_original(&self) -> Option<CrosstermEvent>
Try to convert this event to a crossterm event.