pub enum SubClause<CID, SID>{
Always,
HasAttrValue(SubId<CID, SID>, Attribute, AttrValue),
IsActive(SubId<CID, SID>),
Not(Box<SubClause<CID, SID>>),
And(Box<SubClause<CID, SID>>, Box<SubClause<CID, SID>>),
Or(Box<SubClause<CID, SID>>, Box<SubClause<CID, SID>>),
Xor(Box<SubClause<CID, SID>>, Box<SubClause<CID, SID>>),
}Expand description
SubClause defines unde what conditions the event should be forwarded to the target based on its state.
Variants
Always
Always true
HasAttrValue(SubId<CID, SID>, Attribute, AttrValue)
Check if the target has an attribute with a specific value
IsActive(SubId<CID, SID>)
Check if the target is mounted/registerd depending if it’s a component or a ship
Not(Box<SubClause<CID, SID>>)
Negate another clause
And(Box<SubClause<CID, SID>>, Box<SubClause<CID, SID>>)
Combine two clauses with AND
Or(Box<SubClause<CID, SID>>, Box<SubClause<CID, SID>>)
Combine two clauses with OR
Xor(Box<SubClause<CID, SID>>, Box<SubClause<CID, SID>>)
Combine two clauses with XOR
Implementations