pub struct CommonArg {
pub log_level: LevelFilter,
pub tick_rate: Option<u64>,
pub frame_rate: u64,
}Expand description
Holds the command line arguments to change this lib behavior.
Fields
log_level: LevelFilterThe log level to use. Note that because we are in a TUI, we have no stdout; so as of now, logs are only available via the [ez_tui_std_lib::LogsViewer] component.
tick_rate: Option<u64>The tick rate for the application. Will be set to the frame rate if not provided. Any value above frame rate rarely make sense as the application state will change quicker that it is rendered.
frame_rate: u64The rate at which the view is rendered in the terminal