pub struct CustomLayout<CID>where
CID: EzCptIds,{ /* private fields */ }Expand description
A layout wrapper that makes it easy to create nested layouts.
Implementations
Sourceimpl<CID> CustomLayout<CID>where
CID: EzCptIds,
impl<CID> CustomLayout<CID>where
CID: EzCptIds,
Sourcepub fn named<S: Into<String>>(
name: S,
layout: Layout,
items: VecDeque<LayoutItem<CID>>,
) -> Result<Self>
pub fn named<S: Into<String>>( name: S, layout: Layout, items: VecDeque<LayoutItem<CID>>, ) -> Result<Self>
Create a new CustomLayout with a name
Errors
- [
LayoutError::MismatchConstraintsAndCpts] if the number of areas generated by the layout does not match the number of items in the layout.