pub struct FormCpt<FID, CID, CA, CS, CM>{ /* private fields */ }Expand description
A component responsible for rendering a form.
Implementations
Sourceimpl<FID, CID, CA, CS, CM> FormCpt<FID, CID, CA, CS, CM>
impl<FID, CID, CA, CS, CM> FormCpt<FID, CID, CA, CS, CM>
Sourcepub fn collect(&self) -> FormResult<FID>
pub fn collect(&self) -> FormResult<FID>
Collect this form result as a FormResult.
Sourcepub fn capture_validation(&mut self) -> bool
pub fn capture_validation(&mut self) -> bool
Pass the validation event of this form to all its inputs so they can act on it and return wether or not validation has been handled internally.