pub struct LegendMock { /* private fields */ }Expand description
A mock component to display a colored indicator inside the TUI. The indicator is a simple box alternating its style from a given set of Style when [Self::cycle] is called.
Implementations
Sourceimpl LegendMock
impl LegendMock
Sourcepub fn with_hotkeys(legend: Legend) -> Self
pub fn with_hotkeys(legend: Legend) -> Self
Create a new LegendMock component by picking two colors from the given [Palette].