pub struct Port<CID, SID, CA, CS, CM>{ /* private fields */ }Expand description
The port is the struct that holds all your ships. Like the [View], you’ll only have one port in your app but as many ships as you want.
Again like the [View], the port is the orchestrator of your ships. It will send the forward to/from the ships and your app.
Implementations
Sourceimpl<CID, SID, CA, CS, CM> Port<CID, SID, CA, CS, CM>
impl<CID, SID, CA, CS, CM> Port<CID, SID, CA, CS, CM>
Sourcepub fn register(
&mut self,
id: SID,
ship: BoxedShip<CID, CA, CS, CM>,
) -> Result<()>
pub fn register( &mut self, id: SID, ship: BoxedShip<CID, CA, CS, CM>, ) -> Result<()>
Add a new ship to the port
Errors
PortError::ShipAlreadyRegisteredif that ship ID is already present in the port
Sourcepub fn unregister(&mut self, id: &SID) -> Result<()>
pub fn unregister(&mut self, id: &SID) -> Result<()>
Remove the ship with given id from the port
Errors
PortError::ShipNotFoundif there is no ship with that id in the port
Sourcepub fn registered(&self, id: &SID) -> bool
pub fn registered(&self, id: &SID) -> bool
Check if the ship with given id is registered in the port